@@ -662,6 +662,9 @@ class PortfolioHandler(DBHandler):
         commission = self._commission_percent / 100
         filled_trade = trade.copy()
         
+        filled_price = filled_trade.price
+        if filled_price == 0:
+            filled_price = 0.000000001
 
         if filled_trade.is_hold or not self._is_valid_trade(filled_trade):
             filled_trade.amount = 0
@@ -671,7 +674,7 @@ class PortfolioHandler(DBHandler):
         if filled_trade.is_buy:
             price_adjustment = (1 + commission)
             filled_trade.price = round(current_price * price_adjustment, self._base_precision)
-            filled_trade.amount = round((filled_trade.price * filled_trade.amount) / filled_trade.price,
+            filled_trade.amount = round((filled_trade.price * filled_trade.amount) / filled_price,
                                         self._instrument_precision)
         elif filled_trade.is_sell:
             price_adjustment = (1 - commission)
